package com.ruoyi.project.zjsgfa.mapper;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjSzfxjg;

/**
 * 设计-实钻分析结果Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface SjSzfxjgMapper 
{
    /**
     * 查询设计-实钻分析结果
     * 
     * @param id 设计-实钻分析结果主键
     * @return 设计-实钻分析结果
     */
    public SjSzfxjg selectSjSzfxjgById(Long id);

    /**
     * 查询设计-实钻分析结果列表
     * 
     * @param sjSzfxjg 设计-实钻分析结果
     * @return 设计-实钻分析结果集合
     */
    public List<SjSzfxjg> selectSjSzfxjgList(SjSzfxjg sjSzfxjg);

    /**
     * 新增设计-实钻分析结果
     * 
     * @param sjSzfxjg 设计-实钻分析结果
     * @return 结果
     */
    public int insertSjSzfxjg(SjSzfxjg sjSzfxjg);

    /**
     * 修改设计-实钻分析结果
     * 
     * @param sjSzfxjg 设计-实钻分析结果
     * @return 结果
     */
    public int updateSjSzfxjg(SjSzfxjg sjSzfxjg);

    /**
     * 删除设计-实钻分析结果
     * 
     * @param id 设计-实钻分析结果主键
     * @return 结果
     */
    public int deleteSjSzfxjgById(Long id);

    /**
     * 批量删除设计-实钻分析结果
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjSzfxjgByIds(Long[] ids);

    int deleteSjSzfxjgByJh(String jh);

    int insertSjSzfxjgBatch(List<SjSzfxjg> sjSzfxjgList);

}
